@@ -30,7 +30,7 @@ class DecidirSDK:
         return CardToken(self.url, self.private_key, self.public_key)
 
     def payment(self):
-        return Payment(self.url, self.private_key, self.public_key, self.payment_type)
+        return Payment(self.url, self.private_key, self.public_key, self.payment_type, self.site_id)
 
     def refund(self):
         return Refund(self.url, self.private_key, self.public_key)
