@@ -6,18 +6,7 @@ from iso8601 import parse_date
 from ..response import ok, error
 
 def _format_card(response):
-    if 'card' not in response:
-        return {
-            'id': '',
-            'card_type': '',
-            'last_four_digits': '',
-            'cardholder': {
-                'name': ''
-            },
-            'expiration_month': '',
-            'expiration_year': '',
-        }
-    else:
+    if 'card' in response:
         return {
             'id': response['card']['id'],
             'card_type': 'not_found',
@@ -28,6 +17,29 @@ def _format_card(response):
             'expiration_month': response['card']['expiration_month'],
             'expiration_year': response['card']['expiration_year'],
         }
+        
+    if 'card_data' in response:
+        return {
+            'id': '',
+            'card_type': '',
+            'last_four_digits': response['card_data']['card_number'][-4:],
+            'cardholder': {
+                'name': response['card_data']['card_holder']['name']
+            },
+            'expiration_month': '',
+            'expiration_year': '',
+        }
+    
+    return {
+        'id': '',
+        'card_type': '',
+        'last_four_digits': '',
+        'cardholder': {
+            'name': ''
+        },
+        'expiration_month': '',
+        'expiration_year': '',
+    }
 
 def _format(response):
     if response['status'] == 'accredited':
@@ -118,7 +130,7 @@ class Payment:
         filters = {'siteOperationId': payment_id,
                    'expand':'card_data'}
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
-        list_results = r.json()['response']['results']
+        list_results = r.json()['results']
         if len(list_results) == 1:
             return _format(list_results[0])
         else:
