@@ -5,8 +5,8 @@ def ok(response):
     }
 
 
-def error(message):
+def error(response):
     return {
         'status': 'error',
-        'message': message
+        'response': response
     }
